import React from 'react'
import { commonSettings, switchSettings, elementSettings } from './otherSettings'
import { GroupOutlined } from '@ant-design/icons'
import IconPack from '../../widgets/IconPack'

const groupStyle = {
  groupStyle: {
    title: '控件样式',
    type: 'object',
    properties: {}
  },
  width: {
    title: '元素宽度',
    type: 'string',
    widget: 'percentSlider',
  },
  labelWidth: {
    title: '标签宽度',
    description: '默认值110',
    default: 110,
    type: 'number',
    widget: 'slider',
    max: 400,
    props: {
      hideNumber: true,
    },
  },
}

const layoutWidgets = [
  {
    text: '分组名称',
    name: '分组名称',
    icon: <GroupOutlined />,
    schema: {
      title: '分组名称',
      type: 'object',
      width: '100%',
    },
    setting: {
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
      },
    },
  },
]

const textWidgets = [
  {
    text: '文本',
    name: '文本',
    icon: <IconPack.TextInput />,
    schema: {
      title: '文本',
      type: 'string',
      widget: 'TextInput',
      placeholder: '请输入内容'
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        dependencies: ['widget']
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'InputDefault',
      },
      maxLength: {
        title: '最大长度',
        type: 'number',
        widget: 'number',
        default: 200,
      },
      rules: {
        title: '正则校验',
        type: 'array',
        default: [],
        widget: 'VerifyTextInput',
      },
      uniqueVerify: {
        title: '唯一值校验',
        type: 'string',
        widget: 'select',
        enum: ['表名/字段名'],
        default: null,
        enumNames: ['表名/字段名'],
        // displayType: 'row',
        // labelWidth: 100,
        props: {
          allowClear: true
        }
      },
      tableName: {
        title: '表名',
        type: 'string',
        hidden: "{{formData.uniqueVerify !== '表名/字段名'}}",
        dependencies: ['uniqueVerify'],
      },
      fieldName: {
        title: '字段名',
        type: 'string',
        hidden: "{{formData.uniqueVerify !== '表名/字段名'}}",
        dependencies: ['uniqueVerify'],
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '33%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
        hidden: "{{!['【本人姓名】','【本人部门】'].includes(rootValue.presetValue) }}",
        dependencies: ['presetValue'],
      },
      isQRCode: {
        title: '设备二维码',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        displayType: 'row',
        labelWidth: 120,
        description: '是否解析为二维码格式(手持端专用)',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      addonBefore: {
        title: '前置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      addonAfter: {
        title: '后置标签',
        type: 'string',
        widget: 'InputAddon',
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '多行文本',
    name: '多行文本',
    icon: <IconPack.TextArea />,
    schema: {
      title: '多行文本',
      type: 'string',
      widget: 'TextArea',
      placeholder: '请输入内容'
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
        dependencies: ['widget']
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        widget: 'Placeholder',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      maxLength: {
        title: '最大长度',
        type: 'number',
        widget: 'number',
        default: 500,
        description: '可输入最大字节长度'
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      currentAddress: {
        title: '获取当前地址',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: false,
        description: '自动获取当前地址(手持端专用)',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      rows: {
        title: '高度',
        description: '多行文本占据的行数',
        type: 'number',
        widget: 'number',
        max: 10,
        default: 5,
        widget: 'slider',
        props: {
          hideNumber: true,
        },
      },
      width: {
        title: '元素宽度',
        description: '默认值100%',
        type: 'string',
        widget: 'percentSlider',
        default: '100%',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '数值',
    name: '数值',
    icon: <IconPack.NumberInput />,
    schema: {
      title: '数值',
      type: 'string',
      widget: 'NumberInput',
      presetValue: '0',
      placeholder: '请输入内容',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
        dependencies: ['widget']
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'NumerDefault',
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
        hidden: '{{Boolean(formData.calculateRule)}}',
        dependencies: ['calculateRule']
      },
      calculateRule: {
        title: '计算规则',
        type: 'string',
        widget: 'CalculateRule',
      },
      prefix: {
        title: '前缀',
        type: 'string',
        widget: 'htmlInput',
      },
      formatter: {
        title: '数值格式',
        type: 'string',
        widget: 'Formatting',
      },
      // isStoreFormatter: {
      //   title: '存储为转化值',
      //   type: 'boolean',
      //   displayType: 'row',
      //   labelWidth: 120,
      //   hidden: '{{Boolean(formData.formatter !== "${百分比}")}}',
      //   widget: 'BooleanSwitch',
      //   description: '存储格式化后的值(10%会存储为0.1)'
      // },
      decimalDigits: {
        title: '小数位数',
        type: 'string',
        widget: 'DecimalDigits',
        hidden: '{{!["${小数}", "${货币}"].includes(formData.formatter)}}',
        dependencies: ['formatter']
      },
      min: {
        title: '最小值',
        type: 'string',
        widget: 'NumerDefault',
      },
      max: {
        title: '最大值',
        type: 'string',
        widget: 'NumerDefault',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      addonBefore: {
        title: '前置标签',
        type: 'string',
        widget: 'InputAddon',
      },
      addonAfter: {
        title: '后置标签',
        type: 'string',
        widget: 'InputAddon',
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '富文本',
    name: '富文本',
    icon: <IconPack.RichText />,
    schema: {
      title: '富文本',
      type: 'string',
      widget: 'RichText',
      width: '100%',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '50%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '50%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '编码',
    name: '编码',
    icon: <IconPack.Coding />,
    schema: {
      title: '编码',
      type: 'string',
      widget: 'Coding',
    },
    setting: {
      groupBase: {
        title: '基础信息',
        type: 'object',
        properties: {}
      },
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '30%',
      },
      prefixion: {
        title: '前缀',
        type: 'string',
        displayType: 'row',
        labelWidth: 90,
      },
      codingType: {
        title: '编码方式',
        type: 'string',
        displayType: 'row',
        labelWidth: 90,
        widget: 'select',
        enum: ['1', '2', '3'],
        default: '3',
        enumNames: ['前缀-年份-六位编码', '前缀-年份月份-六位编码', '前缀 -八位编码'],
        description: '{{rootValue.codingType === "1" ?"示例:XJ-2019-000001" : (rootValue.codingType === "2" ? "示例: XJ-201909-000001" : "示例: XJ00000001")}}'
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  }
]

const selectWidgets = [
  {
    text: '下拉框',
    name: '下拉框',
    icon: <IconPack.ComboBox />,
    schema: {
      title: '下拉框',
      type: 'string',
      widget: 'ComboBox',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
        default: '点击下拉选择内容',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      sourceType: {
        title: '来源方式',
        name: '下拉框',
        type: 'string',
        widget: 'SourceType',
        default: '手动输入',
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [{ value: '选项一' }],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          hideCopy: true,
        },
        displayType: 'row',
        labelWidth: 80,
        dependencies: ['sourceType']
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
        dependencies: ['sourceType']
      },
      tableName: {
        title: '表名',
        name: '表名',
        required: '{{formData.sourceType === "表数据"}}',
        hidden: '{{formData.sourceType !== "表数据"}}',
        type: 'string',
        widget: 'TableName',
        dependencies: ['sourceType'],
      },
      fieldName: {
        title: '字段名',
        name: '字段名',
        required: true,
        required: '{{formData.sourceType === "表数据"}}',
        hidden: '{{formData.sourceType !== "表数据"}}',
        type: 'string',
        widget: 'FieldName',
        dependencies: ['sourceType', 'tableName'],
      },
      isMySite: {
        title: '仅显示本人所属的站点',
        required: true,
        default: false,
        hidden: '{{formData.sourceType !== "站点"}}',
        type: 'boolean',
        widget: 'checkbox',
        props: {
          style: {
            paddingLeft: '10px'
          }
        }
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '30%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
        hidden: '{{formData.isEdit}}'
      },
      isSearch: {
        title: '搜索',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
        default: true
      },
      isStoreID: {
        title: '是否存储ID',
        required: true,
        default: false,
        hidden: '{{formData.sourceType !== "站点"}}',
        type: 'boolean',
        widget: 'checkbox',
        width: '40%',
      },
      isEdit: {
        title: '是否可编辑',
        type: 'boolean',
        widget: 'BooleanSwitch',
        displayType: 'row',
        labelWidth: 120,
        description: '勾选后可直接输入选项,可编辑选择仅支持多选',
        hidden: '{{formData.sourceType !== "手动输入"}}'
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '单选框',
    name: '单选框',
    icon: <IconPack.RadioButton />,
    schema: {
      title: '单选框',
      name: '单选框',
      type: 'string',
      widget: 'RadioButton',
      require: true,
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 74,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      sourceType: {
        title: '来源方式',
        name: '单选框',
        type: 'string',
        widget: 'SoruceType',
        default: '手动输入',
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              // required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '复选框',
    name: '复选框',
    icon: <IconPack.CheckBox />,
    schema: {
      title: '复选框',
      name: '复选框',
      type: 'string',
      widget: 'CheckBox',
      require: true,
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      sourceType: {
        title: '来源方式',
        name: '复选框',
        type: 'string',
        widget: 'SoruceType',
        default: '手动输入',
        props: {
          disabled: true
        }
      },
      options: {
        title: '',
        name: '选项',
        type: 'array',
        required: '{{formData.sourceType === "手动输入"}}',
        hidden: '{{formData.sourceType !== "手动输入"}}',
        default: [],
        widget: 'simpleList',
        items: {
          type: 'object',
          properties: {
            value: {
              title: '选项值',
              type: 'string',
              displayType: 'row',
              labelWidth: 75,
              // required: true,
              default: '',
              props: {
                style: {
                  width: '120px',
                  color: 'blue'
                }
              }
            },
          },
        },
        props: {
          // hideMove: true,
          hideCopy: true,
        },
      },
      dictionary: {
        title: '{{formData.sourceType}}',
        name: '{{formData.sourceType}}',
        required: '{{formData.sourceType === "数据字典"}}',
        hidden: '{{formData.sourceType !== "数据字典"}}',
        type: 'string',
        widget: 'Dictionary',
        value: '{{formData.sourceType !== "数据字典" ? null : ""}}',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '开关按钮',
    name: '开关按钮',
    icon: <IconPack.SwitchSelector />,
    schema: {
      title: '开关按钮',
      name: '开关按钮',
      type: 'string',
      widget: 'SwitchSelector'
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 74,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      presetValue: {
        title: '默认值',
        type: 'boolean',
        widget: 'BooleanSwitch',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      showText: {
        title: '显示文字',
        type: 'string',
        widget: 'ShowText',
        default: '开/关',
        description: '示例(开/关)'
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '关联选择',
    name: '关联选择',
    icon: <IconPack.RelevanceSelect />,
    schema: {
      title: '关联选择',
      name: '关联选择',
      type: 'string',
      widget: 'RelevanceSelect',
      placeholder: '请选择内容',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'CascadeDefault',
        dependencies: ['sourceType']
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      fieldParent: {
        title: '父字段名',
        type: 'string',
        required: true,
        widget: 'FieldNames',
      },
      dictionary: {
        title: '数据字典',
        name: '数据字典',
        required: true,
        type: 'string',
        widget: 'Dictionary',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      ...groupStyle,
    }
  },
  {
    text: '级联选择',
    name: '级联选择',
    icon: <IconPack.CascadeSelector />,
    schema: {
      title: '级联选择',
      name: '级联选择',
      type: 'string',
      widget: 'CascadeSelector',
      placeholder: '点击下拉选择内容',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'CascadeDefault',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      sourceType: {
        title: '来源方式',
        name: '来源方式',
        type: 'string',
        widget: 'select',
        default: '城市数据',
        enum: ['城市数据'],
        enumNames: ['城市数据'],
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
]

const businessWidgets = [
  {
    text: '人员选择',
    name: '人员选择',
    icon: <IconPack.PersonSelector />,
    schema: {
      title: '人员选择',
      type: 'string',
      widget: 'PersonSelector',
      placeholder: '点击选择人员',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      role: {
        title: '机构角色',
        type: 'string',
        widget: 'GroupAndRole',
      },
      isMySite: {
        title: '本人站点',
        name: '本人站点',
        required: true,
        default: false,
        type: 'boolean',
        widget: 'checkbox',
        width: '50%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
        width: '50%',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      interactiveType: {
        title: '交互方式',
        type: 'string',
        widget: 'select',
        enum: ['下拉框', '分组模态', '树形模态'],
        default: '下拉框',
        enumNames: ['下拉框', '分组模态', '树形模态'],
        displayType: 'row',
        labelWidth: 80,
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '部门选择',
    name: '部门选择',
    icon: <IconPack.DeptSelector />,
    schema: {
      title: '部门选择',
      type: 'string',
      widget: 'DeptSelector',
      placeholder: '点击选择部门',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      isStoreID: {
        title: '是否存储ID',
        type: 'boolean',
        default: false,
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
  {
    text: '台账选择',
    name: '台账选择',
    icon: <IconPack.AccountSelector />,
    schema: {
      title: '台账选择',
      type: 'string',
      widget: 'AccountSelector',
      placeholder: '点击输入框弹出选择框',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      presetValue: {
        title: '默认值',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      accountName: {
        title: '台账名称',
        name: '台账名称',
        type: 'string',
        widget: 'AccountName',
        required: true,
      },
      fieldshine: {
        title: '映射字段',
        name: '映射字段',
        type: 'array',
        widget: 'Fieldshine',
        required: true,
        dependencies: ['accountName', '$id'],
        default: [],
        description: '单字段映射支持多选，多字段映射仅支持单选',
      },
      siteFilter: {
        title: '站点过滤',
        name: '站点过滤',
        type: 'boolean',
        default: false,
        displayType: 'row',
        labelWidth: 100,
        widget: 'BooleanSwitch',
        description: '开启后只显示自己所属站点数据',
      },
      isMultiple: {
        title: '多选',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        displayType: 'row',
        labelWidth: 100,
        widget: 'BooleanSwitch',
        hidden: '{{formData.fieldshine.length !== 1}}',
      },
      sql: {
        title: 'SQL过滤',
        name: 'SQL过滤',
        type: 'string',
        widget: 'textarea',
        props: {
          placeholder: '示例：部门="XX部门"'
        }
      },
      required: {
        title: '必填',
        type: 'boolean',
        default: false,
        width: '31%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '23%',
      },
      ...groupStyle,
    }
  }
]

const dateWidgets = [
  {
    text: '日期选择',
    name: '日期选择',
    icon: <IconPack.DateTime />,
    schema: {
      title: '日期选择',
      type: 'string',
      widget: 'DateTime',
      placeholder: '请选择日期',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '40%',
        props: {
          style: {
            marginLeft: '10px',
          }
        }
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '30%',
      },
      format: {
        title: '日期格式',
        type: 'string',
        enum: ['date', 'dateTime', 'year', 'month', 'week', 'quarter'],
        default: 'date',
        enumNames: ['日期', '日期时间', '日期年份', '日期月份', '日期周', '日期季度'],
      },
      options: {
        title: '选项',
        type: 'string',
        widget: 'select',
        enum: ['默认为空', '默认为当前时间', '不超过当前时间'],
        default: '默认为空',
        enumNames: ['默认为空', '默认为当前时间', '不超过当前时间'],
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '时间选择',
    name: '时间选择',
    icon: <IconPack.Time />,
    schema: {
      title: '时间选择',
      type: 'string',
      widget: 'Time',
      placeholder: '请选择时间',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
        widget: 'htmlInput',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      presetValue: {
        title: '默认值',
        type: 'string',
        widget: 'TimeDefault',
        format: '{{formData.format}}',
        description: '勾选默认当前时间此处配置无效'
      },
      options: {
        title: '选项',
        type: 'string',
        widget: 'select',
        enum: ['默认为空', '默认为当前时间', '不超过当前时间'],
        default: '默认为空',
        enumNames: ['默认为空', '默认为当前时间', '不超过当前时间'],
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '50%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '50%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    }
  },
]

const fileWidgets = [
  {
    text: '附件',
    name: '附件',
    icon: <IconPack.FileUpload />,
    schema: {
      title: '附件',
      type: 'string',
      widget: 'FileUpload',
      width: '100%',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      fileType: {
        title: '文件类型',
        type: 'string',
        required: true,
        widget: 'select',
        enum: ['全部', '图片', '文档', '音频', '视频'],
        enumNames: ['全部', '图片', '文档', '音频', '视频'],
        default: '全部',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '50%',
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '50%',
      },
      preview: {
        title: '预览',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      download: {
        title: '下载',
        type: 'boolean',
        widget: 'checkbox',
        default: true,
        width: '33%',
      },
      photo: {
        title: '允许从相册选取',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        hidden: "{{!['图片','音频', '视频'].includes(formData.fileType)}}"
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const mapWidgets = [
  {
    text: '地图坐标',
    name: '地图坐标',
    icon: <IconPack.Coordinate />,
    schema: {
      title: '地图坐标',
      type: 'string',
      widget: 'Coordinate',
      placeholder: '请选择坐标位置',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      currentAddress: {
        title: '自动获取',
        type: 'Boolean',
        widget: 'BooleanSwitch',
        description: '自动获取当前地址(手持端专用)'
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '设备选择',
    name: '设备选择',
    icon: <IconPack.Device />,
    schema: {
      title: '设备选择',
      type: 'string',
      widget: 'Device',
      placeholder: '请选择设备',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        required: true,
        type: 'string',
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
  {
    text: '地址位置',
    name: '地址位置',
    icon: <IconPack.SearchLocation />,
    schema: {
      title: '地址位置',
      type: 'string',
      widget: 'SearchLocation',
      placeholder: '请输入位置',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 75,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      title: {
        title: '展示名称',
        type: 'string',
        required: true,
      },
      placeholder: {
        title: '提示语',
        type: 'string',
      },
      description: {
        title: '字段说明',
        type: 'string',
      },
      hiddenCondition: {
        title: '隐藏条件',
        type: 'string',
        description: '所有形态默认显示',
        widget: 'HiddenCondition'
      },
      required: {
        title: '必填',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '25%',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值110',
        default: 110,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const advancedWidgets = [
  {
    text: '关联表单',
    name: '关联表单',
    icon: <IconPack.RelationForm />,
    schema: {
      title: '',
      type: 'string',
      widget: 'RelationForm',
      width: '100%',
      controlShow: '',
    },
    setting: {
      widget: {
        title: '控件类型',
        type: 'string',
        widget: 'WidgetType',
        displayType: 'row',
        labelWidth: 80,
      },
      $id: {
        title: '数据源',
        type: 'string',
        widget: 'FieldNames',
        required: true,
      },
      titleShow: {
        title: '展示名称',
        type: 'string',
        widget: 'htmlInput',
        default: '关联表单',
      },
      description: {
        title: '字段说明',
        type: 'string',
        widget: 'htmlInput',
      },
      disabled: {
        title: '只读',
        type: 'boolean',
        widget: 'checkbox',
        default: false,
        width: '33%',
        props: {
          style: {
            marginLeft: '10px'
          }
        }
      },
      '台账名称': {
        title: '台账名称',
        type: 'string',
        widget: 'AccountName',
        required: true
      },
      '映射字段': {
        title: '映射字段',
        type: 'array',
        widget: 'MappedField',
        required: true,
        default: [],
        dependencies: ['台账名称'],
      },
      '默认显示': {
        title: '默认显示',
        type: 'boolean',
        widget: 'BooleanSwitch',
        default: true,
        displayType: 'row',
        labelWidth: 80,
      },
      '控制规则': {
        title: '控制规则',
        type: 'string',
        displayType: 'row',
        labelWidth: 80,
        widget: 'ControlRules',
      },
      groupStyle: {
        title: '控件样式',
        type: 'object',
        properties: {}
      },
      width: {
        title: '元素宽度',
        type: 'string',
        widget: 'percentSlider',
      },
      labelWidth: {
        title: '标签宽度',
        description: '默认值10',
        default: 10,
        type: 'number',
        widget: 'slider',
        max: 400,
        props: {
          hideNumber: true,
        },
      },
    },
  },
]

const settings = [
  {
    title: '布局控件',
    widgets: layoutWidgets
  },
  {
    title: '文本控件',
    widgets: textWidgets
  },
  {
    title: '选择器控件',
    widgets: selectWidgets,
  },
  {
    title: '业务控件',
    widgets: businessWidgets,
  },
  {
    title: '时间控件',
    widgets: dateWidgets,
  },
  {
    title: '附件控件',
    widgets: fileWidgets,
  },
  {
    title: 'GIS控件',
    widgets: mapWidgets,
  },
  {
    title: '高级控件',
    widgets: advancedWidgets,
  },
]

export default settings