/**
 * 表单组件
 * @author tianxiang
 * @params schemaValues:表单结构与数据，disabledFields：需要只读的字段, disabled:所有字段只读
 * 2023年2月23日 增加参数
 */
import React, { useMemo, useContext, forwardRef, useImperativeHandle, createContext, useState } from 'react'
import FormRender, { useForm } from 'form-render'
import { ConfigProvider, Spin } from 'antd'
import widgets from '../widgets'
import { isObject } from '../../utils'
import { getWatch } from './watch'
import styles from '../../main.less'

const XRender = (props, ref) => {

  useImperativeHandle(ref, () => (
    {
      getValues,
      form,
    }
  ))

  const { schemaValues, disabledFields, disabled, codes } = props
  window.pandaXform = { codes }

  const { formJson, values } = schemaValues
  const { getPrefixCls } = useContext(ConfigProvider.ConfigContext)
  const prefixCls = getPrefixCls('pandaXform')
  const pandaXform = getPrefixCls()
  const [startTime, setStartTime] = useState(new Date().getTime())
  const [loading, setLoading] = useState(true)
  const form = useForm()

  const schemaForm = useMemo(() => {
    let schemaForm = formJson ? (isObject(formJson) ? formJson : JSON.parse(formJson)) : {}
    let parent = schemaForm?.properties
    let parentObj = {}
    if (isObject(parent)) {
      for (let v in parent) {
        let child = parent[v]?.properties
        let childObj = {}
        if (isObject(child)) {
          for (let s in child) {
            let value = ''
            if (Array.isArray(values)) {
              values.forEach(v => {
                if (v.fieldName === s) {
                  value = v.fieldValue
                }
              })
            }
            //只读情况下，去掉必填校验
            let disabledField = child[s].disabled
            let required = child[s].required
            if (disabledFields && !disabledFields.includes(s) && !disabledField) {
              disabledField = true
            }
            if (disabled) {
              disabledField = true
            }
            if (disabledField) {
              required = false
            }
            childObj[s] = { ...child[s], presetValue: value || child[s].presetValue, disabled: disabledField, required }
          }
        }
        if (JSON.stringify(childObj) !== '{}') {
          parentObj[v] = { ...parent[v], properties: childObj }
        }
      }
    }
    return { ...schemaForm, properties: parentObj }
  }, [formJson, values, disabledFields, disabled])

  const watch = useMemo(() => {
    return getWatch(schemaForm, form, startTime)
  }, [schemaForm, form, startTime])

  const getValues = async () => {
    let { data, errors } = await form.submit()
    let formValue = []
    Object.keys(data).map((k) => {
      if (isObject(data[k]) && !['relationForm'].includes(k)) {
        Object.keys(data[k]).map((key) => {
          formValue.push({ fieldName: key, fieldValue: data[k][key] + '' })
        })
      }
    })
    return {
      formValue,
      errors,
      relationForm: data.relationForm
    }
  }

  //初始化时存储外部传的额外数据
  const onMount = () => {
    setTimeout(() => {
      setLoading(false)
    }, 500)
    // form.setValueByPath('extraData', extraData || { codes: { '事件编号': '12312' } })
  }

  return (
    <div className={styles.pandaXform}>
      <Spin spinning={loading} tip="Loading...">
        <FormRender
          configProvider={{ prefixCls: pandaXform }}
          form={form}
          schema={schemaForm}
          mapping={{
            object: 'Header',
          }}
          // scrollToFirstError
          // removeHiddenData={false}
          widgets={widgets}
          watch={watch}
          onMount={onMount}
        />
      </Spin>
    </div>
  )

}

export default forwardRef(XRender)
