import { message } from 'antd'
import { isObject } from '../../utils'
import { formAutomaticComputation, GetSelectItemList, formFieldHideComputation } from '../../apis/process'

export const debounce = (fn) => {
  let t = null
  return function (e) {
    const context = this
    const args = arguments
    if (t) {
      clearTimeout(t)
    }
    t = setTimeout(function () {
      if (typeof fn === 'function') {
        fn.call(context, ...args)
      }
    }, 300)
  }
}

//json值结构转化为数组值
export const jsonToValues = (data, paths) => {
  let formValue = []
  Object.keys(data).map((k) => {
    if (isObject(data[k])) {
      Object.keys(data[k]).map((key) => {
        formValue.push({ fieldName: key, fieldValue: data[k][key] + '' })
      })
    }
  })
  let values = []
  if (Array.isArray(paths)) {
    paths.forEach(v => {
      let fieldName = v.path.split('.')[1]
      let fieldValue = '0'
      let item = formValue.find(s => s.fieldName === fieldName)
      if (item) {
        fieldValue = item.fieldValue
      }
      values.push({
        fieldName,
        fieldValue,
      })
    })
  }
  return {
    formValue: values,
    relationForm: data.relationForm
  }
}

const getWidgetInfo = (json, widget) => {
  let AutoCalculate = []
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          if (child[s].widget === widget) {
            AutoCalculate.push({
              gorupName: v,
              fieldName: s,
              ...child[s],
              targetPath: `${v}.${s}`,
            })
          }
        }
      }
    }
  }
  return AutoCalculate
}

//获取含有隐藏条件形态
const getHiddenWidget = (json) => {
  let HiddenWidget = []
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          if (Array.isArray(child[s].hiddenRules) && child[s].hiddenRules.length) {
            HiddenWidget.push({
              gorupName: v,
              fieldName: s,
              ...child[s],
              targetPath: `${v}.${s}`,
            })
          }
        }
      }
    }
  }
  return HiddenWidget
}

const getPath = (json, filed) => {
  let parent = json?.properties
  if (isObject(parent)) {
    for (let v in parent) {
      let child = parent[v]?.properties
      if (isObject(child)) {
        for (let s in child) {
          if (s === filed) {
            return `${v}.${s}`
          }
        }
      }
    }
  }
  return ''
}

const getFieldName = (configs, tableName) => {
  let path = ''
  configs.forEach(v => {
    if (v['台账名称'] === tableName) {
      path = v.$id
    }
  })
  return path
}

const formAutomatic = async (params) => {
  if ((new Date().getTime() - params.startTime) < 2000) return
  let param = {
    tableName: params.tableName,
    filedFormulas: params.filedFormulas,
    relationForm: params.relationForm,
    values: jsonToValues(params.form.getValues(), params.paths).formValue
  }
  const { code, data, msg } = await formAutomaticComputation(param)
  if (code === 0) {
    if (Array.isArray(data)) {
      data.forEach(v => {
        let path = getPath(params.schema, v.fieldName)
        if (path) {
          params.form.setValueByPath(path, v.fieldValue + '')
        }
      })
    }
  } else {
    message.error(msg)
  }
}

//如果该分组下所有字段隐藏那就影隐藏分组
const getGroupHidden = (form, schema, gorupName) => {
  let gorupSchema = schema?.properties?.[gorupName]?.properties || {}
  let hidden = true
  for (let key in gorupSchema) {
    let sunSchema = form.getSchemaByPath(`${gorupName}.${key}`)
    if (!sunSchema.hidden) {
      hidden = false
    }
  }
  return hidden
}

const formFieldHide = async (params) => {
  let param = {
    tableName: params.tableName,
    filedFormulas: params.filedFormulas,
    relationForm: params.relationForm,
    values: jsonToValues(params.form.getValues(), params.paths).formValue
  }
  const { code, data } = await formFieldHideComputation(param)
  if (code === 0) {
    if (Array.isArray(data)) {
      data.forEach(v => {
        let path = getPath(params.schema, v.fieldName)
        if (path) {
          params?.form?.setSchemaByPath(path, { ...params?.form?.getSchemaByPath(path), hidden: v.fieldValue })
          let hidden = getGroupHidden(params?.form, params.schema, params.gorupName)
          params?.form?.setSchemaByPath(params.gorupName, { ...params?.form?.getSchemaByPath(params.gorupName), hidden: hidden })
        }
      })
    }
  }
}

const Automatic = debounce(formAutomatic)

const fieldHide = debounce(formFieldHide)

//自动计算监听/隐藏条件监听
const getAutoWatch = (schema, form, startTime) => {
  let watch = {}
  let paths = []
  let { relationForm } = form?.getValues()
  const configs = relationForm?.configs || []
  const AutoCalculate = getWidgetInfo(schema, 'NumberInput')
  const HiddenWidget = getHiddenWidget(schema)
  if (Array.isArray(AutoCalculate)) {
    AutoCalculate.forEach(item => {
      const { gorupName, fieldName, rules, calculateRule } = item
      if (Array.isArray(rules)) {
        rules.forEach(s => {
          if (schema.tableName === s.tableName) {
            if (Array.isArray(s.fields)) {
              s.fields.forEach(v => {
                let path = getPath(schema, v)
                if (path) {
                  paths.push({ gorupName, type: ['AutoCalculate'], path: path, fieldName, formula: calculateRule })
                }
              })
            }
          } else {
            let path = getFieldName(configs, s.tableName)
            if (path) {
              paths.push({ gorupName, type: ['AutoCalculate'], path, fieldName, formula: calculateRule })
            }
          }
        })
      }
    })
  }
  if (Array.isArray(HiddenWidget)) {
    HiddenWidget.forEach(item => {
      const { gorupName, fieldName, hiddenRules, hiddenCondition } = item
      if (Array.isArray(hiddenRules)) {
        hiddenRules.forEach(v => {
          if (Array.isArray(v.fields)) {
            v.fields.forEach(s => {
              let path = getPath(schema, s)
              if (path) {
                paths.push({
                  gorupName,
                  type: ['HiddenWidget'],
                  path,
                  fieldName,
                  formula: hiddenCondition
                })
              }
            })
          }
        })
      }
    })
  }
  if (Array.isArray(paths)) {
    paths.forEach(v => {
      watch[v.path] = () => {
        let params = {
          ...v,
          tableName: schema.tableName,
          filedFormulas: paths.filter(s => s.path === v.path),
          form: form,
          paths: paths,
          relationForm,
          schema: schema,
          startTime
        }
        if (v.type.includes('AutoCalculate')) {
          Automatic(params)
        }
        if (v.type.includes('HiddenWidget')) {
          fieldHide(params)
        }
      }
    })
  }
  return watch
}

const getSelectItemList = async (params) => {
  if ((new Date().getTime() - params.startTime) < 2000) return
  const { sourcePath, form, targetPath, dictionary, value } = params
  const { code, data, msg } = await GetSelectItemList({ nodeName: dictionary })
  if (code === 0) {
    let array = data.filter(v => v.nodeName === value)
    if (Array.isArray(array) && array.length) {
      form.setValueByPath(targetPath, array[0].nodeValue)
    }
  }
}

//关联选择监听
const getSelectWatch = (schema, form, startTime) => {
  let watch = {}
  const RelevanceSelect = getWidgetInfo(schema, 'RelevanceSelect')
  if (Array.isArray(RelevanceSelect)) {
    RelevanceSelect.forEach(v => {
      let path = getPath(schema, v.fieldParent)
      if (path) {
        watch[path] = (value) => {
          if (value) {
            let params = {
              startTime,
              sourcePath: path,
              targetPath: v.targetPath,
              form: form,
              dictionary: v.dictionary,
              value
            }
            debounce(getSelectItemList)(params)
          }
        }
      }
    })
  }
  return watch
}

export const getWatch = (schema, form, startTime) => {
  return {
    ...getAutoWatch(schema, form, startTime),
    ...getSelectWatch(schema, form, startTime)
  }
}