import React, { useState, useMemo, forwardRef, useContext, useImperativeHandle } from 'react'
import { ConfigProvider } from 'antd'
import FormRender, { useForm } from 'form-render'
import widgets from './widgets'
import { isObject } from '../../../../../utils'
import { getWatch } from '../../../../FormRender/watch'

const BaseForm = (props, ref) => {

  useImperativeHandle(ref, () => (
    {
      getValues
    }
  ))

  const { schemaForm, config, formState, disabled } = props
  const { getPrefixCls } = useContext(ConfigProvider.ConfigContext)
  const prefixCls = getPrefixCls('pandaXform')
  const pandaXform = getPrefixCls()
  const form = useForm()
  const [startTime, setStartTime] = useState(new Date().getTime())

  //表单需要显示的字段
  const field = useMemo(() => {
    const { fieldGroup, editFieldGroup, addFieldGroup } = config
    let field = []
    if (formState === '详情') {
      field = fieldGroup ? fieldGroup.split(',') : []
    } else if (formState === '添加') {
      field = addFieldGroup ? addFieldGroup.split(',') : []
    } else if (formState === '编辑') {
      field = editFieldGroup ? editFieldGroup.split(',') : []
    }
    return field
  }, [config, formState])

  const schema = useMemo(() => {
    const { group, values } = schemaForm
    let parent = group?.properties
    let parentObj = {}
    if (isObject(parent)) {
      for (let v in parent) {
        let child = parent[v]?.properties
        let childObj = {}
        if (isObject(child)) {
          for (let s in child) {
            if (field.includes(s)) {
              let value = ''
              values.forEach(v => {
                if (v.fieldName === s) {
                  value = v.fieldValue
                }
              })
              let disabledField = child[s].disabled
              if (disabled) {
                disabledField = true
              }
              childObj[s] = { ...child[s], presetValue: value || child[s].presetValue, disabled: disabledField }
            }
          }
        }
        if (JSON.stringify(childObj) !== '{}') {
          parentObj[v] = { ...parent[v], properties: childObj }
        }
      }
    }
    return { ...group, properties: parentObj }
  }, [schemaForm, field, disabled])

  const watch = useMemo(() => {
    return getWatch(schema, form, startTime)
  }, [schema, form, startTime])

  const getValues = async () => {
    let { data, errors } = await form.submit()
    let formValue = []
    Object.keys(data).map((k) => {
      if (isObject(data[k]) && !['relationForm'].includes(k)) {
        Object.keys(data[k]).map((key) => {
          formValue.push({ fieldName: key, fieldValue: data[k][key] + '' })
        })
      }
    })
    return {
      formValue,
      errors,
    }
  }

  return (
    <div className={prefixCls}>
      <FormRender
        configProvider={{ prefixCls: pandaXform }}
        mapping={{
          object: 'Header',
        }}
        form={form}
        schema={schema}
        widgets={widgets}
        watch={watch}
      />
    </div>
  )

}

export default forwardRef(BaseForm)