import React, { useMemo, useState, useRef, useLayoutEffect, useEffect } from 'react'
import styles from './index.less'
import {
  GetAccountPageList,
  GetAccountConfigInfo,
  GetTableGroupMeta,
  GetTableDataInfo,
  SaveTableDataInfo,
  EditTableDataInfo,
  DeleteTableDataInfo
} from '../../../../apis/process'
import { Table, Button, Modal, message, Popconfirm, ConfigProvider } from 'antd'
import { SnippetsOutlined, PlusOutlined, FormOutlined, DeleteOutlined } from '@ant-design/icons'
import { GetTableJson } from '../../../../apis/process'
import BaseForm from './BaseForm'
import { isObject } from '../../../../utils'
import Drag from '../../../components/Drag'

const icons = {
  '详情': <SnippetsOutlined />,
  '编辑': <FormOutlined />,
  '删除': <DeleteOutlined />,
}
let formStateStr = '添加'

const getFormDataObj = (formData) => {
  let formDataObj = {}
  Object.keys(formData).map((k) => {
    if (isObject(formData[k])) {
      Object.keys(formData[k]).map((key) => {
        formDataObj[key] = formData[k][key] || ''
      })
    }
  })
  return formDataObj
}

const RelationForm = (props) => {

  const codes = window?.pandaXform?.codes || {}
  const { value, onChange, schema, addons } = props
  const { disabled, '台账名称': accountName, '默认显示': defaultShow, '控制规则': controlShow, titleShow, '映射字段': mappedField } = schema
  const [config, setConfig] = useState({ webShowFieldGroup: '', fieldGroup: '' })
  const [dataSource, setDataSource] = useState([])
  const [groupMeta, setGroupMeta] = useState([])
  const [visible, setVisible] = useState(false)
  const [formState, setFormState] = useState('详情')
  const [row, setRow] = useState({})
  const [schemaGroup, setSchemaGroup] = useState({})
  const [schemaValues, setSchemaValues] = useState([])
  const [loading, setLoading] = useState(false)
  const baseFormRef = useRef(null)

  const formDataObj = useMemo(() => {
    let formDataObj = {}
    if (addons) {
      formDataObj = getFormDataObj(addons?.formData)
    }
    return formDataObj
  }, [addons?.formData])

  const show = useMemo(() => {
    if (addons) {
      let str = controlShow
      try {
        let matchArr = str ? str.match(/\{(.+?)\}/g) : []
        if (Array.isArray(matchArr)) {
          matchArr?.forEach(v => {
            let value = v.replace(/{/g, '').replace(/}/g, '')
            let valueArr = value ? value.split('.') : []
            let fieldValue = formDataObj[valueArr[1]]
            str = str.replace(v, `'${fieldValue}'`)
          })
        }
        str = str.replace(/=/g, '==')
        str = str.replace(/and/g, '&&')
        str = str.replace(/or/, '||')
        if (str && eval(str)) {
          // addons.setSchemaByPath(addons.dataPath, { ...schema, hidden: !schema.hidden })
          return !defaultShow
        }
        return defaultShow
      } catch {
        return defaultShow
      }
    }
    return defaultShow
  }, [formDataObj, defaultShow])

  const localForm = useMemo(() => {
    const { addFieldGroup } = config
    let array = []
    let field = addFieldGroup ? addFieldGroup.split(',') : []
    const getFieldValue = (s, formDataObj, codes) => {
      return codes ? (codes[s.fromField] || formDataObj[s.fromField]) : formDataObj[s.fromField]
    }
    field.forEach(v => {
      if (Array.isArray(mappedField)) {
        mappedField.forEach(s => {
          if (s.toField === v) {
            array.push({ fieldName: s.toField, fieldValue: getFieldValue(s, formDataObj, codes) })
          }
        })
      }
    })
    return array
  }, [formDataObj, config, mappedField, codes, dataSource])

  const columns = useMemo(() => {
    let btn = ['详情']
    if (!disabled) {
      btn = ['详情', '编辑', '删除']
    }
    const { webShowFieldGroup } = config
    let field = webShowFieldGroup ? webShowFieldGroup.split(',').filter(v => v) : []
    let array = []
    if (field.length > 0) {
      array.push({ title: '序号', width: 50, align: 'center', render: (_, r, i) => i + 1 })
      field.forEach(v => {
        array.push({
          title: v,
          dataIndex: v,
          key: v,
          ellipsis: {
            visibleTitle: false,
          },
        })
      })
      array.push({
        title: '操作',
        dataIndex: '',
        key: 'action',
        width: btn.length === 1 ? 80 : btn.length * 40,
        fixed: 'right',
        render: (t, r) => {
          return (
            <div style={{ display: 'flex', justifyContent: 'center' }}>
              {
                btn.map(v => {
                  if (v === '删除') {
                    return (
                      <Popconfirm
                        // disabled={selectedRowKeys.length}
                        title='确定要删除数据吗？'
                        onConfirm={() => rowClick(v, r)}
                        onCancel={() => { }}
                        okText='确定'
                        cancelText='取消'
                      >
                        <Button type='link' icon={icons[v]} title={v} />
                      </Popconfirm>
                    )
                  }
                  return (
                    <Button
                      type='link'
                      icon={icons[v]}
                      title={v}
                      onClick={() => rowClick(v, r)}
                    />
                  )
                })
              }
            </div>
          )
        }
      })
    }
    return array
  }, [disabled, config, dataSource, formState])

  const rowClick = async (v, r) => {
    if (addons) {
      setRow(r)
      if (v === '详情') {
        setSchemaValues(getItem(r))
        setVisible(true)
      } else if (v === '编辑') {
        setSchemaValues(getItem(r))
        setVisible(true)
      } else if (v === '删除') {
        deleteTableInfo(r)
      }
      formStateStr = v
      setFormState(v)
    }
  }

  const getItem = (data, max) => {
    if (Array.isArray(data)) {
      let obj = { ...row, ID: row.ID }
      data.forEach(v => {
        obj[v.fieldName] = v.fieldValue
      })
      return obj
    } else {
      let values = []
      for (let key in data) {
        if (max) {
          values.push({ FieldName: key, FieldValue: data[key] })
        } else {
          values.push({ fieldName: key, fieldValue: data[key] })
        }
      }
      return values
    }
  }

  const deleteTableInfo = (r) => {
    let listItem = { type: 'delete', accountTable: accountName, id: r.ID, values: getItem('delete', r) }
    let relationForm = addons.getValue('relationForm') || { configs: [], data: [] }
    if (r.ID.includes('前端ID')) {
      let list = relationForm.data.filter(v => v.id !== r.ID)
      addons.setValue('relationForm', { ...relationForm, data: list })
    } else {
      addons.setValue('relationForm', { ...relationForm, data: [...relationForm.data, listItem] })
    }
    let tableData = dataSource.filter(v => v.ID !== r.ID)
    setDataSource(tableData)
    onChange(`${tableData.length}`)
  }

  const getConfig = async () => {
    let { code, data, msg } = await GetAccountConfigInfo(accountName)
    if (code === 0) {
      setConfig(data)
      getTableData(data.addFieldGroup ? data.addFieldGroup.split(',') : [])
    } else {
      message.error(msg)
    }
  }

  const getGroupMeta = async () => {
    setLoading(true)
    const { code, data, msg } = await GetTableJson(accountName)
    if (code === 0) {
      if (data && typeof data === 'string') {
        setSchemaGroup(JSON.parse(data))
      }
    } else {
      message.error(msg)
    }
    setLoading(false)
  }

  const getQueryWheres = (addFieldGroup) => {
    let queryWheres = []
    let formDataObj = getFormDataObj(addons?.formData)
    addFieldGroup.forEach(v => {
      if (Array.isArray(mappedField)) {
        mappedField.forEach(s => {
          if (s.toField === v) {
            queryWheres.push({ field: s.toField, type: '等于', value: codes ? (codes[s.fromField] || formDataObj[s.fromField]) : formDataObj[s.fromField] })
          }
        })
      }
    })
    let relationForm = addons.getValue('relationForm') || { configs: [], data: [] }
    relationForm?.configs.forEach(v => {
      v.queryWheres = queryWheres.map(v => { return { fieldName: v.field, fieldValue: v.value } })
    })
    return queryWheres
  }

  const getTableData = async (addFieldGroup) => {
    if (!addons) return
    let queryWheres = getQueryWheres(addFieldGroup)
    if (!queryWheres.length) {
      message.info('映射字段配置错误！')
    }
    let params = {
      accountName: accountName,
      direction: 'desc',
      timeField: '录入时间',
      pageIndex: 0,
      pageSize: 0,
      queryWheres
    }
    if (queryWheres.every(v => !v.value)) return
    const { code, data, msg } = await GetAccountPageList(params)
    if (code === 0) {
      let tableData = JSON.parse(data.jsonData)
      if (Array.isArray(tableData)) {
        setDataSource(tableData)
        onChange(`${tableData.length}`)
      } else {
        setDataSource([])
        onChange(`${0}`)
      }
    } else {
      message.error(msg)
    }
  }

  const getData = () => {
    getConfig()
    getGroupMeta()
  }

  const onOk = async () => {
    if (addons) {
      const { formValue, errors } = await baseFormRef.current.getValues()
      if (errors.length) {
        return message.error('请按照提示完善表单内容')
      }
      let type = row.ID.includes('前端ID') ? 'add' : 'edit'
      let itemData = { type, accountTable: accountName, id: row.ID, values: formValue }
      if (formStateStr !== '添加') {
        let array = []
        if (Array.isArray(dataSource)) {
          dataSource.forEach(v => {
            if (v.ID === row.ID) {
              array.push({ ...v, ...getItem(formValue) })
            } else {
              array.push({ ...v })
            }
          })
        }
        setDataSource(array)
        setTimeout(() => {
          onChange(`${array.length}`)
        }, 0)

      } else if (formStateStr === '添加') {
        let array = [getItem(formValue), ...dataSource]
        setDataSource(array)
        setTimeout(() => {
          onChange(`${array.length}`)
        }, 0)
      }
      let relationForm = addons.getValue('relationForm') || { configs: [], data: [] }
      let listArray = relationForm.data.filter(v => v.id !== itemData.id)
      listArray.push({ ...itemData })
      addons.setValue('relationForm', { ...relationForm, data: listArray })
      setVisible(false)
    }
  }

  const addClick = () => {
    if (!localForm.length) {
      return message.info('台账添加字段未配置!')
    }
    if (addons) {
      if (JSON.stringify(schemaGroup) === '{}') {
        return message.info(`台账[${accountName}]未配置形态!`)
      }
      setRow({ ID: `前端ID${new Date().getTime()}` })
      setFormState('添加')
      setSchemaValues(localForm)
      formStateStr = '添加'
      setVisible(true)
    }
  }

  useEffect(() => {
    if (accountName) {
      getData()
    }
  }, [accountName])

  useLayoutEffect(() => {
    //初始化关联表单配置信息，初始显示隐藏
    if (addons) {
      let relationForm = addons.getValue('relationForm') || { configs: [], data: [] }
      addons.setValue('relationForm', { ...relationForm, configs: [...relationForm.configs, schema] })
    }
  }, [])

  return (
    <div className={styles.relationForm} style={{ display: (addons && !show) ? 'none' : 'block' }}>
      <div className={styles.header}>
        <span className='account-header-title'>{titleShow}</span>
        {disabled ? null : <Button className={styles.headerBtn} type='primary' size='middle' icon={<PlusOutlined />} onClick={addClick}>添加</Button>}
      </div>
      <Table
        loading={loading}
        rowKey={r => JSON.stringify(r)}
        size='small'
        bordered
        columns={columns}
        dataSource={dataSource}
        pagination={{ total: dataSource.length, showTotal: (value) => `总计 ${value} 条` }}
      />
      <Drag
        title={accountName}
        width='80%'
        bodyStyle={{ height: '700px', overflow: 'auto' }}
        visible={visible}
        onOk={onOk}
        onCancel={() => setVisible(false)}
        destroyOnClose
      >
        <BaseForm
          schemaForm={{
            group: schemaGroup,
            values: schemaValues,
          }}
          formState={formState}
          config={config}
          ref={baseFormRef}
          disabled={!['编辑', '添加'].includes(formState)}
        />
      </Drag>
    </div>
  )

}

export default RelationForm