import React, { useEffect, useMemo, useState } from 'react'
import { Input, message, Modal, Spin, Checkbox, Row, Col, Radio } from 'antd'
import { UserAddOutlined } from '@ant-design/icons'
import styles from '../index.less'
import { getUserSelector } from '../../../../../apis/process'
import Drag from '../../../../components/Drag'

const getUSerName = (groupList, value, isMultiple, property) => {
  let users = []
  if (Array.isArray(groupList)) {
    groupList.forEach(v => {
      if (Array.isArray(v.userList)) {
        if (isMultiple) {
          v.userList.forEach(s => {
            if (value.split(',').includes(s[property])) {
              users.push(s)
            }
          })
        } else {
          let values = v.userList.filter(s => s[property] == value)
          if (values.length) {
            users = values
          }
        }
      }
    })
  }
  return users.map(v => v.userName).join(',')
}

const UserGroup = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, isMultiple, placeholder, role, isStoreID, isMySite, presetValue } = schema
  const property = isStoreID ? 'userID' : 'userName'
  const [groupPerson, setGroupPerson] = useState([])
  const [visible, setVisible] = useState(false)
  const [loading, setLoading] = useState(false)
  const [check, setCheck] = useState([])
  const [radio, setRadio] = useState(null)
  const [search, setSearch] = useState(null)

  const groupList = useMemo(() => {
    let array = []
    if (Array.isArray(groupPerson)) {
      groupPerson.forEach(v => {
        let userList = []
        if (Array.isArray(v.userList)) {
          v.userList.forEach(s => {
            userList.push({ ...s, userID: s.userID })
          })
        }
        array.push({ ...v, userList })
      })
    }
    return array
  }, [groupPerson])

  const valueShow = useMemo(() => {
    if (value) {
      if (property === 'userID') {
        return getUSerName(groupList, value, isMultiple, property)
      }
    }
    return value
  }, [groupList, isMultiple, value, property])

  const groupPersonShow = useMemo(() => {
    if (search) {
      let array = []
      groupList.forEach(v => {
        let userList = []
        let noShowParent = !v.ouName.includes(search)
        v.userList.forEach(s => {
          let noShow = !s.userName.includes(search)
          if (!noShow) {
            noShowParent = false
          }
          userList.push({ ...s, noShow: !noShowParent ? noShowParent : noShow })
        })
        array.push({ ...v, userList, noShow: noShowParent })
      })
      return array
    }
    return groupList
  }, [search, groupList])

  const onOk = () => {
    if (addons) {
      onChange(isMultiple ? check.join(',') : radio)
    }
    setVisible(false)
  }

  const inputChange = (value) => {
    setSearch(value)
  }

  const checkChange = (value) => {
    setCheck(value)
  }

  const radioChange = (e) => {
    setRadio(e.target.value)
  }

  const checkGroup = (v, type) => {
    let array = v.userList.map(v => v.userName)
    if (type === 'true') {
      setCheck(check.filter(v => !array.includes(v)))
    } else {
      setCheck(Array.from(new Set([...check, ...array])))
    }
  }

  const getGorupType = (v, checkCount) => {
    if (checkCount === 0) {
      return 'false'
    } else if (v.userList.length === checkCount) {
      return 'true'
    }
    return 'other'
  }

  const inputFocus = async () => {
    if (addons) {
      getData()
      setVisible(true)
    }
  }

  const getCount = (v) => {
    let array = v.userList.filter(s => check.includes(s[property]))
    if (Array.isArray(array)) {
      return array.length
    }
    return 0
  }

  const getData = async () => {
    setLoading(true)
    const { code, data, msg } = await getUserSelector(role, isMySite ? userID : false)
    if (code === 0) {
      if (Array.isArray(data.groupList)) {
        setGroupPerson(data.groupList)
      }
    } else {
      message.error(msg)
    }
    setLoading(false)
  }

  useEffect(() => {
    if (isMultiple) {
      setCheck(value ? value.split(',') : [])
    } else {
      setRadio(value)
    }
  }, [isMultiple, value])

  useEffect(() => {
    if (isStoreID) {
      getData()
    }
  }, [])

  useEffect(() => {
    onChange(presetValue)
  }, [presetValue])

  return (
    <div className={styles.personGroup}>
      <Input
        disabled={disabled}
        value={valueShow}
        placeholder={disabled ? null : placeholder}
        onClick={inputFocus}
        addonAfter={disabled ? null : <UserAddOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={inputFocus} />}
        style={{ width: '100%' }}
      />
      <Drag
        title='人员选择器'
        visible={visible}
        bodyStyle={{ height: 450 }}
        onCancel={() => setVisible(false)}
        onOk={onOk}
        getContainer={false}
      >
        <Spin
          spinning={loading}
        >
          <Input.Search
            placeholder='请输入姓名'
            allowClear
            enterButton
            value={search}
            onChange={(e) => inputChange(e.target.value)}
          />
          {
            isMultiple ?
              <Checkbox.Group
                style={{ width: '100%', height: '400px', overflow: 'auto', marginTop: '10px' }}
                value={check}
                onChange={checkChange}
              >
                {
                  groupPersonShow.map(v => {
                    let checkCount = getCount(v)
                    let type = getGorupType(v, checkCount)
                    return (
                      <div key={v.ouid} className={styles.groupUser} style={{ display: v.noShow ? 'none' : 'block' }}>
                        <div className={styles.groupName} onClick={() => checkGroup(v, type)}>
                          <span className={styles.groupCheck} type={type}></span>
                          <span>{v.ouName + `${checkCount}/${v.userList.length}`}</span>
                        </div>
                        <Row style={{ paddingLeft: '40px' }}>
                          {
                            v.userList.map(s => {
                              return (
                                <Col span={8} key={s.userID} style={{ margin: '8px 0', display: s.noShow ? 'none' : 'block' }}>
                                  <Checkbox
                                    value={s[property]}
                                  >
                                    <div>{s.userName}</div>
                                  </Checkbox>
                                </Col>
                              )
                            })
                          }
                        </Row>
                      </div>
                    )
                  })
                }
              </Checkbox.Group>
              :
              <Radio.Group
                value={radio}
                onChange={radioChange}
                style={{ width: '100%', height: '400px', overflow: 'auto', marginTop: '10px' }}
              >
                {
                  groupPersonShow.map(v => {
                    let checkCount = getCount(v)
                    let type = getGorupType(v, checkCount)
                    return (
                      <div className={styles.groupUser} style={{ display: v.noShow ? 'none' : 'block' }} key={v.ouid}>
                        <div className={styles.groupName}>
                          <span style={{ fontSize: '14px', fontWeight: 'bold' }}>{v.ouName}</span>
                        </div>
                        <Row style={{ paddingLeft: '40px' }}>
                          {
                            v.userList.map(s => {
                              return (
                                <Col span={8} style={{ margin: '8px 0', display: s.noShow ? 'none' : 'block' }} key={s.userID}>
                                  <Radio
                                    value={s[property]}
                                  >
                                    <div>{s.userName}</div>
                                  </Radio>
                                </Col>
                              )
                            })
                          }
                        </Row>
                      </div>
                    )
                  })
                }
              </Radio.Group>
          }
        </Spin>
      </Drag>
    </div>
  )

}

export default UserGroup