import React, { useEffect, useMemo, useState } from 'react'
import { Select, message } from 'antd'
import { getUserSelector } from '../../../../../apis/process'

const UserSelect = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, presetValue, isMultiple, placeholder, role, isStoreID, isMySite } = schema
  const property = isStoreID ? 'userID' : 'userName'
  const [pullDown, setPullDown] = useState([])

  const valueShow = useMemo(() => {
    if (isMultiple) {
      return value ? value.split(',') : []
    }
    return value || null
  }, [value, isMultiple])

  const selectFocus = async () => {
    const { code, data, msg } = await getUserSelector(role, isMySite ? userID : false)
    if (code === 0) {
      if (data) {
        setPullDown(data.dropdownList.map(v => { return { label: v.userName, value: v[property] } }))
      } else {
        setPullDown([])
      }
    } else {
      message.info(msg)
    }
  }

  const selectChange = (value) => {
    if (addons) {
      onChange(isMultiple ? value.join(',') : value)
    }
  }

  useEffect(() => {
    onChange(presetValue)
  }, [presetValue])

  useEffect(() => {
    if (isStoreID) {
      selectFocus()
    }
  }, [])

  return (
    <Select
      mode={isMultiple ? 'multiple' : null}
      placeholder={disabled ? null : placeholder}
      value={valueShow}
      disabled={disabled}
      showArrow={!disabled}
      showSearch={true}
      style={{ width: '100%' }}
      onFocus={selectFocus}
      onChange={selectChange}
      options={pullDown}
      getPopupContainer={(targterNode) => targterNode.parentElement || document.body}
    >
    </Select>
  )

}

export default UserSelect