import React, { useState, useRef, useEffect, useContext } from 'react'
import { Input, Modal } from 'antd'
import { CompassOutlined, ExclamationCircleOutlined } from '@ant-design/icons'
import {
  ArcGISSceneMap,
  ClickQuery,
  geomUtils,
  GraphicsLayer,
  Graphic
} from '@wisdom-map/arcgismap'
import point from './img/point.png'
import { isObject } from '../../../../utils'
import Drag from '../../../components/Drag'

let geometrystr = ''
let gisInfo = {}
let layer = 0

const initMapConfig = [
  {
    "basemaps": [
      {
        "id": "高德地形",
        "title": "高德地形",
        "thumbnailUrl": "assets/images/thumbnail/thumbnail_1.jpg",
        "baseLayers": [
          {
            "title": "高德地形",
            "icon": "assets/images/thumbnail/thumbnail_1.jpg",
            "layerType": "amap-v",
            "url": "",
            "opacity": 1,
            "visible": false,
            "useProxy": false,
            "proxyUrl": "",
            "style": null,
            "extent": "",
            "baseLayer": "",
            "levelStart": "",
            "levelEnd": "",
            "levelEndEnlarge": false,
            "resolution": "",
            "origin": "",
            "tileMatrix": "",
            "zoom": 0
          }
        ]
      }
    ],
    "id": "wlgcs",
    "title": "wlgcs",
    "icon": "",
    "layerType": "PipenetLayer",
    "url": "CityInterface/rest/services/MapServer.svc/wlgcs",
    "opacity": 1,
    "showLegend": true,
    "visible": true,
    "useProxy": true,
    "proxyUrl": "",
    "extent": "12733684.9026203,3560132.6351416963,12734623.874243027,3560857.1781486557",
    "baseLayer": "",
    "levelStart": null,
    "levelEnd": null,
    "resolution": "",
    "origin": "",
    "tileMatrix": "",
    "wmtsUrl": "",
    "schemename": "物联港",
    "roles": "15,27,28,1015,1035,1036,1040,1041,1042,1037,1038,1039,43,57,60,61,62,63,64,65,1003,1004",
    "areaName": "江夏区",
    "boundColor": "#86C8F8",
    "backgroundColor": "#009688",
    "boundWidth": "5px",
    "backgroundOpacity": "0.6",
    "exportScheme": "pandagis"
  },
  {
    "basemaps": [
      {
        "id": "高德地形",
        "title": "高德地形",
        "thumbnailUrl": "assets/images/thumbnail/thumbnail_1.jpg",
        "baseLayers": [
          {
            "title": "高德地形",
            "icon": "assets/images/thumbnail/thumbnail_1.jpg",
            "layerType": "amap-v",
            "url": "",
            "opacity": 1,
            "visible": false,
            "useProxy": false,
            "proxyUrl": "",
            "style": null,
            "extent": "",
            "baseLayer": "",
            "levelStart": "",
            "levelEnd": "",
            "levelEndEnlarge": false,
            "resolution": "",
            "origin": "",
            "tileMatrix": "",
            "zoom": 0
          }
        ]
      }
    ],
    "id": "luanzhou",
    "title": "luanzhou",
    "icon": "",
    "layerType": "dynamic",
    "url": "CityInterface/rest/services/MapServer.svc/luanzhou",
    "opacity": 1,
    "showLegend": true,
    "visible": true,
    "useProxy": true,
    "proxyUrl": "",
    "extent": "13209667.350188782,4825282.3802740965,13220086.323771724,4831701.695887157",
    "baseLayer": "",
    "levelStart": null,
    "levelEnd": null,
    "resolution": "",
    "origin": "",
    "tileMatrix": "",
    "wmtsUrl": "",
    "schemename": "前端绘制管网测试方案",
    "roles": null,
    "areaName": "滦州市",
    "boundColor": "#7de825",
    "backgroundColor": "#000000",
    "boundWidth": "10px",
    "backgroundOpacity": "0.6",
    "exportScheme": "arcgis"
  },
  {
    "basemaps": [
      {
        "id": "高德地形",
        "title": "高德地形",
        "thumbnailUrl": "assets/images/thumbnail/thumbnail_1.jpg",
        "baseLayers": [
          {
            "title": "高德地形",
            "icon": "assets/images/thumbnail/thumbnail_1.jpg",
            "layerType": "amap-v",
            "url": "",
            "opacity": 1,
            "visible": false,
            "useProxy": false,
            "proxyUrl": "",
            "style": null,
            "extent": "",
            "baseLayer": "",
            "levelStart": "",
            "levelEnd": "",
            "levelEndEnlarge": false,
            "resolution": "",
            "origin": "",
            "tileMatrix": "",
            "zoom": 0
          }
        ]
      }
    ],
    "id": "luanzhouZS",
    "title": "luanzhouZS",
    "icon": "",
    "layerType": "dynamic",
    "url": "CityInterface/rest/services/MapServer.svc/luanzhouZS",
    "opacity": 1,
    "showLegend": true,
    "visible": true,
    "useProxy": true,
    "proxyUrl": "",
    "extent": "13210364.94854749,4824486.87832399,13222264.608150885,4831691.679813754",
    "baseLayer": "",
    "levelStart": null,
    "levelEnd": null,
    "resolution": "",
    "origin": "",
    "tileMatrix": "",
    "wmtsUrl": "",
    "schemename": "业务平台",
    "roles": null,
    "areaName": "滦州市",
    "boundColor": "#86C8F8",
    "backgroundColor": "#000000",
    "boundWidth": "5px",
    "backgroundOpacity": "0.6",
    "exportScheme": "pandagis"
  }
]

const Device = (props) => {

  const mapConfig = window.globalConfig?.mapsettings?.layers || initMapConfig
  const { addons, value, onChange, schema } = props
  const { placeholder, disabled, parent } = schema
  const [visible, setVisible] = useState(false)
  const layersConifg = { layers: mapConfig }
  let clickref = useRef(null)
  let view = useRef(null)

  const getMapInfo = (mapObj, Map) => {
    setTimeout(() => {
      if (mapObj) {
        view.current = mapObj
        let arr = (value && value.split(',')) || []
        let obj = (arr.length === 2) ? { point: { x: Number(arr[0]), y: Number(arr[1]) } } : {}
        if (arr.length === 2) {
          view.current.goTo({
            center: geomUtils.toGeometry({ x: Number(arr[0]), y: Number(arr[1]) }),
            zoom: 15
          })
        }
        clickref.current = new ClickQuery({
          view: view.current,
          offsetX: -150,
          offsetY: -310,
          continuous: true,
          ...obj,
          callback: ({ clickPoint, matchPoint, data }) => {
            gisInfo = {}
            if (layer) {
              view.current.map.remove(layer)
            }
            if (matchPoint) {
              geometrystr = `${matchPoint.x},${matchPoint.y}`
              gisInfo = { layerName: data.layerName, gisCode: data.attributes.code }
            } else if (clickPoint) {
              geometrystr = `${clickPoint.x},${clickPoint.y}`
              layer = new GraphicsLayer({
                id: 'ok-layers',
              })
              if (geometrystr) {
                const polypointGraphic = new Graphic({
                  geometry: geomUtils.toGeometry({
                    x: Number(geometrystr.split(',')[0]),
                    y: Number(geometrystr.split(',')[1])
                  }),
                  symbol: {
                    type: "picture-marker",
                    url: point,
                    width: "20px",
                    height: "20px"
                  },
                })
                layer.add(polypointGraphic)
                view.current.map.add(layer)
              }
            }
          }
        })
      }
    }, 500)
  }

  const iconClick = () => {
    if (addons) {
      setVisible(true)
    }
  }

  const onOk = () => {
    onChange(geometrystr)
    let { paths } = addons.getSchemaByPath('#')
    if (Array.isArray(paths)) {
      paths.forEach(v => {
        let values = addons.getValue(v)
        if (isObject(values)) {
          for (let key in values) {
            if (key === 'GIS编码' && gisInfo.gisCode) {
              addons.setValue(`${v}.${key}`, gisInfo.gisCode)
            }
            if (key === 'GIS图层' && gisInfo.layerName) {
              addons.setValue(`${v}.${key}`, gisInfo.layerName)
            }
          }
        }
      })
    }
    setVisible(false)
  }

  const onCancel = () => {
    setVisible(false)
  }

  return (
    <div>
      <Input
        disabled={disabled}
        value={value}
        placeholder={placeholder}
        onClick={iconClick}
        addonAfter={disabled ? null : <CompassOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={iconClick} />}
        style={{ width: '100%' }}
      />
      <Drag
        visible={visible}
        title='设备选择'
        width={'80%'}
        onOk={onOk}
        onCancel={onCancel}
        cancelText={'取消'}
        okText={'确定'}
        bodyStyle={{ height: 600, overflowY: 'auto', position: 'relative' }}
        getContainer={true}
      >
        <ArcGISSceneMap
          getMapInfo={getMapInfo}
          widgets={[]}
          config={layersConifg}
        />
      </Drag>
    </div>
  )
}

export default Device