import React, { useEffect } from 'react'
import { TimePicker } from 'antd'
import locale from 'antd/lib/date-picker/locale/zh_CN'
import moment from 'moment'

const Time = (props) => {

  const { value, onChange, schema, addons } = props
  const { presetValue, currentDate, defaultCurrent, options, disabled, placeholder } = schema

  const disabledDate = (current) => {
    if (options === '不超过当前时间') {
      return current && current.format('HH:mm:ss') > moment().format('HH:mm:ss')
    } else {
      return false
    }
  }

  const timeChange = (time, timeStr) => {
    onChange(moment(time).format('YYYY-MM-DD HH:mm:ss'))
  }

  useEffect(() => {
    if (addons) {
      let value = presetValue || (options === '默认为当前时间' ? moment(new Date()).format('HH:mm:ss') : null)
      addons.setValue(addons.dataPath, value)
    } else {
      onChange(presetValue)
    }
  }, [presetValue, options])

  return (
    <TimePicker
      style={{ width: '100%' }}
      value={value ? moment(value, 'HH:mm:ss') : null}
      onChange={timeChange}
      disabledDate={disabledDate}
      locale={locale}
      disabled={disabled}
      placeholder={!disabled ? placeholder : ''}
      getPopupContainer={(targterNode) => targterNode.parentElement || document.body}
    />
  )

}

export default Time