import React, { useState, useEffect, useMemo } from 'react'
import { Checkbox } from 'antd'
import { GetSelectItemList } from '../../../../apis/process'

const CheckBox = (props) => {

  const { value, onChange, schema, addons } = props
  const { presetValue, disabled, sourceType, options, dictionary } = schema
  const [dictionaryList, setDictionaryList] = useState([])

  const enums = useMemo(() => {
    switch (sourceType) {
      case '手动输入':
        return Array.isArray(options) ? options.map(v => v.value) : []
      case '数据字典':
        return Array.isArray(dictionaryList) ? Array.from([...new Set(dictionaryList.map(v => v.nodeName))]) : []
      default:
        return []
    }
  }, [sourceType, options, dictionaryList])

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue)
    } else {
      onChange(presetValue)
    }
  }, [presetValue])

  const onFocus = async () => {
    const { data } = await GetSelectItemList({ nodeName: dictionary })
    if (Array.isArray(data)) {
      setDictionaryList(data)
    }
  }

  const checkChange = (value) => {
    if (addons) {
      addons.setValue(addons.dataPath, value.join(','))
    }
  }

  useEffect(() => {
    if (sourceType === '数据字典' && dictionary) {
      onFocus()
    }
  }, [sourceType, dictionary])

  return (
    <Checkbox.Group
      disabled={disabled}
      onChange={checkChange}
      value={value ? value.split(',') : []}
    >
      {enums.map(v => <Checkbox key={v} value={v}>{v}</Checkbox>)}
    </Checkbox.Group>
  )
}

export default CheckBox