import React, { useState, useMemo, useEffect } from 'react'
import { Select, message } from 'antd'
import { GetSelectItemList, GetFieldValueFromTable, getStationListByUserID, getStationIDListByUserID } from '../../../../apis/process'

const { Option } = Select

const ComboBox = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { placeholder, disabled, sourceType, options, dictionary, tableName, fieldName, presetValue, isMultiple, isEdit, isMySite, isSearch, isStoreID } = schema
  const [dictionaryList, setDictionaryList] = useState([])
  const [tableData, setTableData] = useState([])
  const [site, setSite] = useState([])

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue)
    } else {
      onChange(presetValue)
    }
  }, [presetValue])

  const valueShow = useMemo(() => {
    if (isMultiple || isEdit) {
      return value ? value.split(',') : []
    } else {
      return value || null
    }
  }, [isEdit, isMultiple, value])

  const enums = useMemo(() => {
    switch (sourceType) {
      case '手动输入':
        return Array.isArray(options) ? options.map(v => v.value) : []
      case '数据字典':
        return Array.isArray(dictionaryList) ? dictionaryList.map(v => v.nodeValue) : []
      case '表数据':
        return Array.isArray(tableData) ? tableData : []
      case '站点':
        return Array.isArray(site) ? site : []
      default:
        return []
    }
  }, [sourceType, options, dictionaryList, tableData, site])

  const children = useMemo(() => {
    let children = []
    if (Array.isArray(enums)) {
      enums.forEach(v => {
        if (sourceType === '站点') {
          children.push(<Option key={isStoreID ? v.stationID : v.stationName}>{v.stationName}</Option>)
        } else {
          children.push(<Option key={v}>{v}</Option>)
        }
      })
    }
    return children
  }, [sourceType, enums, isStoreID])

  const handleChange = value => {
    if (isMultiple || isEdit) {
      onChange(value.join(','))
    } else {
      onChange(value)
    }
  }

  const onFocus = async () => {
    if (addons) {
      if (sourceType === '数据字典') {
        if (!dictionary) {
          return message.error('请选择数据字典！')
        }
        const { data } = await GetSelectItemList({ nodeName: dictionary })
        if (Array.isArray(data)) {
          setDictionaryList(data)
        }
      }
      if (sourceType === '表数据') {
        if (!tableName) {
          return message.info('请选择表名!')
        }
        if (!fieldName) {
          return message.info('请选择字段名!')
        }
        const { code, data, msg } = await GetFieldValueFromTable(tableName, fieldName)
        if (code === 0) {
          if (Array.isArray(data)) {
            setTableData(data.filter(v => v))
          } else {
            setTableData([])
          }
        } else {
          message.error(msg)
        }
      }
      if (sourceType === '站点') {
        const { code, data, msg } = await getStationIDListByUserID(userID, !isMySite)
        if (code === 0) {
          if (Array.isArray(data)) {
            setSite(data)
          } else {
            setSite([])
          }
        } else {
          message.error(msg)
        }
      }
    }
  }

  return (
    <Select
      onFocus={onFocus}
      style={{ width: '100%' }}
      mode={isEdit ? 'tags' : (isMultiple ? 'multiple' : '')}
      disabled={disabled}
      showArrow={!disabled}
      showSearch={isSearch}
      value={valueShow}
      placeholder={placeholder}
      onChange={handleChange}
      allowClear
      getPopupContainer={(targterNode) => targterNode.parentElement || document.body}
    >
      {children}
    </Select>
  )

}

export default ComboBox
