import React, { useEffect, useState } from 'react'
import { Select, message } from 'antd'
import { GetSelectItemList } from '../../../../apis/process'

const { Option } = Select

const RelevanceSelect = (props) => {

  const { value, onChange, schema, addons } = props
  const { disabled, placeholder, fieldParent, dictionary, presetValue } = schema
  const [options, setOptions] = useState([])

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue)
    } else {
      onChange(presetValue)
    }
  }, [presetValue])

  const selectChange = (value) => {
    if (addons) {
      onChange(value)
    }
  }

  const onfocus = async () => {
    if (!addons) return
    if (!dictionary) {
      return message.error('缺少数据字典!')
    }
    const { code, data, msg } = await GetSelectItemList({ nodeName: dictionary })
    if (code === 0) {
      if (Array.isArray(data)) {
        let filterKey = null
        Object.keys(addons.formData).forEach(v => {
          if (addons.formData[v]) {
            Object.keys(addons.formData[v]).forEach(s => {
              if (fieldParent === s) {
                filterKey = addons.formData[v][s]
              }
            })
          }
        })
        if (filterKey) {
          setOptions(data.filter(v => v.nodeName === filterKey))
        } else {
          setOptions(data)
        }
      }
    } else {
      message.error(msg)
    }
  }

  return (
    <Select
      value={value}
      onFocus={onfocus}
      style={{ width: '100%' }}
      onChange={selectChange}
      disabled={disabled}
      placeholder={!disabled ? placeholder : null}
    >
      {
        options.map((v, i) => <Option value={v.nodeValue} key={i}>{v.nodeValue}</Option>)
      }
    </Select>
  )

}

export default RelevanceSelect