import React, { useEffect, useMemo, useState } from 'react'
import { InputNumber } from 'antd'

function formatMoney(number, places, symbol, thousand, decimal) {
  number = number || 0;
  places = !isNaN(places = Math.abs(places)) ? places : 2;
  symbol = symbol !== undefined ? symbol : "$";
  thousand = thousand || ",";
  decimal = decimal || ".";
  var negative = number < 0 ? "-" : "",
    i = parseInt(number = Math.abs(+number || 0).toFixed(places), 10) + "",
    j = (j = i.length) > 3 ? j % 3 : 0;
  return symbol + negative + (j ? i.substr(0, j) + thousand : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + thousand) + (places ? decimal + Math.abs(number - i).toFixed(places).slice(2) : "");
}
const NumberInput = (props) => {

  const { value, onChange, schema, addons } = props
  const { disabled, presetValue, placeholder, prefix, formatter, decimalDigits, isStoreFormatter, addonBefore, addonAfter, min, max } = schema

  const [once, setOnce] = useState(true)

  useEffect(() => {
    if (addons) {
      addons.setValueByPath(addons.dataPath, presetValue || '0')
    } else {
      onChange(presetValue || '0')
    }
  }, [presetValue])

  const inputChange = (value) => {
    if (addons) {
      onChange(`${value}`)
    }
  }

  const formatterFn = (value) => {
    if (value) {
      if (formatter === '${百分比}') {
        return `${value}%`
      } else if (formatter === '${货币}') {
        return formatMoney(Number(value), Number(decimalDigits))
      } else if (formatter === '${整数}') {
        return `${parseInt(value)}`
      } else if (formatter === '${小数}') {
        return Number(value).toFixed(Number(decimalDigits))
      } else if (formatter) {
        return `${value}${formatter}`
      }
    }
    return value
  }

  return (
    <InputNumber
      min={min || Number.MIN_SAFE_INTEGER}
      max={max || Number.MAX_SAFE_INTEGER}
      step={(formatter === '${百分比}' && isStoreFormatter) ? 0.01 : 1}
      addonBefore={addonBefore}
      addonAfter={addonAfter}
      prefix={prefix}
      placeholder={placeholder}
      disabled={disabled}
      value={Number(value)}
      formatter={formatterFn}
      onChange={inputChange}
      style={{ width: '100%' }}
    />
  )

}

export default NumberInput