import React, { useState } from 'react';

export function downloadFunc(url, name, target = '_self') {
  const a = document.createElement('a');
  a.href = url;
  a.target = target;
  a.download = name;
  a.click();
  a.remove();
}

/**
 *  @Description: 校验文件的名称是否包含特殊字符
 *  @Params: {Object: File} file file对象 { special:Boolean } 是否去除/的匹配
 *  @Date: 2021/12/8
 *  @Author: ChenLong
 *  @Return {Object} {type: error | success ,content: 提示...}
 * */
export function filenameVerification(file, special) {
  // 文件名含有特殊字符  提示不能上传   {+,:/?#[]@!$&\\*+;=}
  // 规则对象(flag)
  var flag = !special ? new RegExp('[`~!@#$^&*=|{}\':;\',\\[\\]/?~！@#￥&*——|{}【】‘；：”“\'。，、？]') : new RegExp('[`~!@#$^&*=|{}\':;\',\\[\\]?~！@#￥&*——|{}【】‘；：”“\'。，、？]');
  if (flag.test(file.name)) {
    return {
      type: 'error',
      content: `文件名格式错误，请检查文件名是否含有特殊字符${'~!@#$^&*=|{}\':;\',\\[\\]/?~！@#￥&*——|{}【】‘；：”“\'。，、？'}`,
    };
  }
  return {
    type: 'success',
    content: `上传成功！`,
  };
}

/**
 *  @Description: 判断数据类型
 *  @Params: 参数描述
 *  @Date: 2021/12/17
 *  @Author: ChenLong
 *  @Return: '[object 各自对相应的类型]','[object Function]', '[object Object]', '[object Array]', '[object String]', '[object Number]', '[object Boolean]', '[object Undefined]', '[object Null]', '[object Date]'
 * */
export function returnDataType(data) {
  return Object.prototype.toString.call(data);
}

export function parseSQL2JSON(str) {
  let finalArray = [];
  // 1.支持以下字符， > < 都包含等于
  // 2.关键字和关键字符必须前后空格
  // 3.仅支持单个关键字或者关键字符的筛选条件

  let queryWhere = [];

  /** @Tips: 台账名和字段的逻辑 */
  // 1. 解析台账名.字段名[.n](资产台账.编码[.n]) 是表明加载的台账和台账选择器返回的字段名，并且需要验证该字段【不可为空】
  let strArray = str.split('?');
  let accountNameAndField = strArray[0];

  let accountArray = accountNameAndField.split('.');
  let accountName = accountArray[0]; // 台账
  let returnField = accountArray[1]; // 需要返回的字段
  queryWhere.push({
    field: returnField,
    type: '不等于',
    value: '',
  });
  let isMultiple = accountArray.includes('n'); // 是否多选
  /** @End: 台账解析结束 */

  let otherCondition = strArray[1];
  /** @Tips: 1. 判断是否多条件 and */
  let otherConditionArray = otherCondition.split('and').map(item => item.trim());
  /** @Tips: 2. 解析规则，判断是否有关键词并组成JSON */
  otherConditionArray.forEach(item => {

  });

  return {
    accountName,
    isMultiple,
    returnField,
    queryWheres: [],
  };
}

//判断是否为JSON字符串
export const isJson = (json) => {
  if (typeof json === 'string') {
    try {
      let obj = JSON.parse(json)
      if (typeof obj === 'object' && obj) {
        return true
      }
    } catch (e) {
      return false
    }
  }
  return false
}

export const isObject = (obj) => typeof obj === 'object'

//防抖
export const debounce = (fn) => {
  let t = null
  return function (e) {
    const context = this
    const args = arguments
    if (t) {
      clearTimeout(t)
    }
    t = setTimeout(function () {
      fn.call(context, args)
    }, 500)
  }
}